# Changelog

## [0.22.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.21.0...v0.22.0) (2026-03-16)


### Features

* **project:** update bussdcc dependency and modify USB camera config handling ([016c39a](https://github.com/jbussdieker/bussdcc-hardware/commit/016c39a7161cc6e0687f8bb844b7bbb0eef1c0f9))

## [0.21.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.20.0...v0.21.0) (2026-03-11)


### Features

* **project:** update Device import paths and bump bussdcc dependency ([b7e8ef6](https://github.com/jbussdieker/bussdcc-hardware/commit/b7e8ef6363d33e663d26ef311a8db56bcfa0f26a))

## [0.20.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.19.0...v0.20.0) (2026-03-10)


### Features

* **usb_camera:** use Literal type for format field in USBCameraConfig ([b51d815](https://github.com/jbussdieker/bussdcc-hardware/commit/b51d81562b9c54b8ef204b7510ce5afd426b7ab2))

## [0.19.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.18.0...v0.19.0) (2026-03-10)


### Features

* add GPIO bus and digital_output device with protocol abstraction ([b4fa818](https://github.com/jbussdieker/bussdcc-hardware/commit/b4fa81889fb1509e492705f4fa795f99c3611a78))
* **digital_output:** enhance configuration and state management ([84bcb3a](https://github.com/jbussdieker/bussdcc-hardware/commit/84bcb3a5438e8d5bd4d79d9a0a13ca55d70db631))

## [0.18.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.17.0...v0.18.0) (2026-03-10)


### Features

* **nau7802:** enhance configuration and reading capabilities ([5dca456](https://github.com/jbussdieker/bussdcc-hardware/commit/5dca45686febdaac3e37a02964f046f4ed5cf2e9))
* **usb_camera:** add buffer size and frame flushing configuration ([f857b99](https://github.com/jbussdieker/bussdcc-hardware/commit/f857b99943499895849225fa5bc24eec17c9101c))

## [0.17.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.16.1...v0.17.0) (2026-03-10)


### Features

* **deps:** update bussdcc dependency to 0.38.0 ([2978852](https://github.com/jbussdieker/bussdcc-hardware/commit/2978852191309fb730afe16418587f3152106d7d))

## [0.16.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.16.0...v0.16.1) (2026-03-09)


### Documentation

* **readme:** update and expand documentation ([f9fcfcb](https://github.com/jbussdieker/bussdcc-hardware/commit/f9fcfcba82780b9c7dcb6aeddbb855fe8e445ec7))

## [0.16.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.15.1...v0.16.0) (2026-03-09)


### Features

* **config:** enhance dataclass configurations with metadata ([5d35eda](https://github.com/jbussdieker/bussdcc-hardware/commit/5d35eda71b9bb8bc49411658f492ec0843baf529))

## [0.15.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.15.0...v0.15.1) (2026-03-09)


### Bug Fixes

* **device:** handle missing device path in DS18B20 driver ([7e362f7](https://github.com/jbussdieker/bussdcc-hardware/commit/7e362f7f516a86d6d6e8500d61ebfd31787698fc))

## [0.15.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.14.1...v0.15.0) (2026-03-09)


### Features

* **device:** enhance error handling and update dependencies ([49191d9](https://github.com/jbussdieker/bussdcc-hardware/commit/49191d9792808e1a95528be93f97cbf895d9f767))

## [0.14.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.14.0...v0.14.1) (2026-03-08)


### Bug Fixes

* **dependencies:** update dependencies and modify Makefile ([30e8ed3](https://github.com/jbussdieker/bussdcc-hardware/commit/30e8ed369b3cf99e43464d169c32528c914c72d7))

## [0.14.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.13.0...v0.14.0) (2026-03-08)


### Features

* **bus, device:** refactor device definitions and enhance USB camera config ([29c18d2](https://github.com/jbussdieker/bussdcc-hardware/commit/29c18d2c2faceabc4214c2bccf8d744eb4b62a3e))

## [0.13.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.12.1...v0.13.0) (2026-03-08)


### Features

* **bus, device:** introduce bus and device definitions ([7619838](https://github.com/jbussdieker/bussdcc-hardware/commit/76198386eb28bb57f3ecc07cb679832a0d4cc6e7))

## [0.12.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.12.0...v0.12.1) (2026-03-07)


### Bug Fixes

* **i2c:** return proper interface ([505596a](https://github.com/jbussdieker/bussdcc-hardware/commit/505596a27a3d995d16f8df27169e031183b1b4bc))

## [0.12.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.11.0...v0.12.0) (2026-03-07)


### Features

* **pyproject, i2c, ds18b20, nau7802, relay:** update dependencies and refactor device access ([2062297](https://github.com/jbussdieker/bussdcc-hardware/commit/2062297776cfff0387b3387d1e16c5aed5cd0ab2))


### Bug Fixes

* **pyproject:** update bussdcc dependency to v0.33.1 ([a4c386a](https://github.com/jbussdieker/bussdcc-hardware/commit/a4c386a9ff242aa90b2024f2b185cdffa15aeda4))

## [0.11.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.2...v0.11.0) (2026-03-07)


### Features

* **pyproject:** update bussdcc dependency to v0.33.0 ([0766304](https://github.com/jbussdieker/bussdcc-hardware/commit/076630465d10dac47a88b19ca05586ce0947fb82))

## [0.10.2](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.1...v0.10.2) (2026-03-06)


### Bug Fixes

* **pyproject:** update bussdcc dependency to v0.32.2 ([8c5604c](https://github.com/jbussdieker/bussdcc-hardware/commit/8c5604c2d81fa0d20085fe2e356731ccc8114356))

## [0.10.1](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.10.0...v0.10.1) (2026-03-06)


### Bug Fixes

* **pyproject:** update bussdcc dependency to v0.32.1 ([82505bf](https://github.com/jbussdieker/bussdcc-hardware/commit/82505bf55f403bb5e81bf5c88dc685baa1b927b3))

## [0.10.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.9.0...v0.10.0) (2026-03-06)


### Features

* **pyproject:** update bussdcc dependency to v0.32.0 ([0eb5622](https://github.com/jbussdieker/bussdcc-hardware/commit/0eb56228e2b6a2d9b3fa6cecaeb19ddf3445b346))

## [0.9.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.8.0...v0.9.0) (2026-03-05)


### Features

* **pyproject:** update bussdcc dependency version ([efa4e04](https://github.com/jbussdieker/bussdcc-hardware/commit/efa4e042cd7262579f42e3dce3739c1f8934658a))

## [0.8.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.7.0...v0.8.0) (2026-03-04)


### Features

* **pyproject:** update dependencies and entry points ([c8ffeb7](https://github.com/jbussdieker/bussdcc-hardware/commit/c8ffeb7f3853daad193756d8bb7ab90a1aa7be5b))

## [0.7.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.6.0...v0.7.0) (2026-03-04)


### Features

* **device, bus:** update initialization to use config dictionaries ([5d56ba5](https://github.com/jbussdieker/bussdcc-hardware/commit/5d56ba5d0396a0e3a54a1bcd444cd91f27e8a48a))

## [0.6.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.5.0...v0.6.0) (2026-03-04)


### Features

* **bus, device:** add VideoBus and W1Bus support ([9c03d48](https://github.com/jbussdieker/bussdcc-hardware/commit/9c03d48c73d2c64199a5b8eb09f1ae48f7092975))
* **gpio, relay, ds18b20:** add GPIO bus and relay device support ([a6858b2](https://github.com/jbussdieker/bussdcc-hardware/commit/a6858b2e96aa6d13d65806efa25cd0bf75b85133))

## [0.5.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.4.0...v0.5.0) (2026-03-04)


### Features

* **pyproject:** add entry points for hardware components ([303804f](https://github.com/jbussdieker/bussdcc-hardware/commit/303804f25cc5ec4be0361108a89a07d326139000))

## [0.4.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.3.0...v0.4.0) (2026-03-03)


### Features

* **ds18b20:** add DS18B20 temperature sensor support ([f5c567b](https://github.com/jbussdieker/bussdcc-hardware/commit/f5c567b7aacf3d9eb92f156e3f04aae5c8f9c798))
* **usb_camera:** add support for USB camera integration ([a321d8a](https://github.com/jbussdieker/bussdcc-hardware/commit/a321d8a5fd34eef1d50ec74bffcbfa0d09eddd7d))

## [0.3.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.2.0...v0.3.0) (2026-03-03)


### Features

* **deps:** update bussdcc to version 0.28.0 ([423176c](https://github.com/jbussdieker/bussdcc-hardware/commit/423176cd9a5c4d90aa6acd27b086604d9d5fd46d))

## [0.2.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.1.0...v0.2.0) (2026-03-03)


### Features

* **pump:** add Pump device support ([2858dfb](https://github.com/jbussdieker/bussdcc-hardware/commit/2858dfb41426a8ecdd1394a5b6b2924b797944ce))

## 0.1.0 (2026-03-02)


### Features

* **i2c:** add I2CBus and NAU7802 device support ([12c78df](https://github.com/jbussdieker/bussdcc-hardware/commit/12c78dfcf0d715f4c2cc5aee57e03df285483f5a))
* initial commit ([01b3136](https://github.com/jbussdieker/bussdcc-hardware/commit/01b313647497bffa5c14babe7bb0801c9d082cf0))


### Documentation

* **readme:** expand README with project concepts ([ee73fc1](https://github.com/jbussdieker/bussdcc-hardware/commit/ee73fc17cbfd46a17021e3678108df9681922541))
